package com.dsk.cscec.controller;


import com.dsk.common.core.controller.BaseController;
import com.dsk.common.core.domain.R;
import com.dsk.common.excel.ExcelUtils;
import com.dsk.common.exception.ServiceException;
import com.dsk.cscec.domain.CbQuantitySummary;
import com.dsk.cscec.domain.bo.CbProjectBaseBo;
import com.dsk.cscec.service.ICbQuantitySummaryService;
import com.dsk.system.domain.vo.SysUserImportVo;
import lombok.RequiredArgsConstructor;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import sun.reflect.generics.tree.Tree;

import java.util.List;
import java.util.Map;
import java.util.TreeMap;
import java.util.stream.Collectors;

/**
 * 成本-工料汇总基本表(CbQuantitySummary)表控制层
 *
 * @author lcl
 * @since 2024-02-05 11:06:56
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/cb/quantity/summary")
public class CbQuantitySummaryController extends BaseController {

    private final ICbQuantitySummaryService baseService;

    /**
     * 工料汇总科目树
     * @return
     */
    @GetMapping(value = "/subjectTree")
    public R<Map<String, Object>> subjectTree(@PathVariable CbProjectBaseBo bo){
        return R.ok(baseService.subjectTree(bo));
    }

    /**
     * 已记录月份集合
     */
    @GetMapping(value = "/monthList")
    public R<List<String>> monthList(@PathVariable CbProjectBaseBo bo){
        return R.ok(baseService.monthList(bo));
    }

    /**
     * 数据导入
     */
    @PostMapping(value = "/importData")
    public R<Void> importFile(@RequestPart("file") MultipartFile file) throws Exception {
        //识别Excel内容
        List<CbQuantitySummary> importList = new ExcelUtils<>(CbQuantitySummary.class).importExcelAllSheet(file.getInputStream(), 1);
        if (importList.isEmpty()) {
            throw new ServiceException("表格中不存在待导入数据!");
        }
        importList = importList.stream().parallel()
                .filter(item -> !ObjectUtils.isEmpty(item.getCbName()))
                .peek(item -> {
                    item.setProjectId(1L);
                    item.setCbStage(0);
                }).collect(Collectors.toList());
        if (importList.isEmpty()) {
            throw new ServiceException("表格中不存在有效数据数据!");
        }
        return toAjax(baseService.saveBatch(importList));
    }

}

